==> infi.pypi_manager-0.4.17.tar.gz: infi.pypi_manager-0.4.17/setup.py <==

SETUP_INFO = dict(
    name = 'infi.pypi_manager',
    version = '0.4.17',
    author = 'Arnon Yaari',
    author_email = 'arnony@infinidat.com',

    url = 'https://github.com/Infinidat/infi.pypi_manager',
    license = 'PSF',
    description = """A small tool we use to migrate/mirror distributions from pypi.python.org to our local djangopypi server""",
    long_description = """A small tool we use to migrate/mirror distributions from pypi.python.org to our local djangopypi server""",

    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers = [
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: Python Software Foundation License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],

    install_requires = ['infi.execute', 'docopt', 'PrettyTable', 'infi.pyutils', 'requests', 'distribute'],
    namespace_packages = ['infi'],

    package_dir = {'': 'src'},
    package_data = {'': []},
    include_package_data = True,
    zip_safe = False,

    entry_points = dict(
        console_scripts = ['mirror_package = infi.pypi_manager.scripts.mirror_package:mirror_package', 'hard_install = infi.pypi_manager.scripts.hard_install:main', 'compare_pypi_repos = infi.pypi_manager.scripts.compare_pypi_repos:main', 'get_python_dependencies = infi.pypi_manager.dependencies:main', 'get_python_licenses = infi.pypi_manager.scripts.licenses:main'],
        gui_scripts = [],
        ),
)

if SETUP_INFO['url'] is None:
    _ = SETUP_INFO.pop('url')

def setup():
    from setuptools import setup as _setup
    from setuptools import find_packages
    SETUP_INFO['packages'] = find_packages('src')
    _setup(**SETUP_INFO)

if __name__ == '__main__':
    setup()

==> infi.pypi_manager-0.4.18.tar.gz: infi.pypi_manager-0.4.18/setup.py <==

SETUP_INFO = dict(
    name = 'infi.pypi_manager',
    version = '0.4.18',
    author = 'Guy Rozendorn',
    author_email = 'guy@rzn.co.il',

    url = 'https://github.com/Infinidat/infi.pypi_manager',
    license = 'PSF',
    description = """A small tool we use to migrate/mirror distributions from pypi.python.org to our local djangopypi server""",
    long_description = """A small tool we use to migrate/mirror distributions from pypi.python.org to our local djangopypi server""",

    # http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers = [
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "License :: OSI Approved :: Python Software Foundation License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],

    install_requires = ['infi.execute', 'docopt', 'PrettyTable', 'infi.pyutils', 'requests', 'distribute'],
    namespace_packages = ['infi'],

    package_dir = {'': 'src'},
    package_data = {'': []},
    include_package_data = True,
    zip_safe = False,

    entry_points = dict(
        console_scripts = ['mirror_package = infi.pypi_manager.scripts.mirror_package:mirror_package', 'hard_install = infi.pypi_manager.scripts.hard_install:main', 'compare_pypi_repos = infi.pypi_manager.scripts.compare_pypi_repos:main', 'get_python_dependencies = infi.pypi_manager.dependencies:main', 'get_python_licenses = infi.pypi_manager.scripts.licenses:main'],
        gui_scripts = [],
        ),
)

if SETUP_INFO['url'] is None:
    _ = SETUP_INFO.pop('url')

def setup():
    from setuptools import setup as _setup
    from setuptools import find_packages
    SETUP_INFO['packages'] = find_packages('src')
    _setup(**SETUP_INFO)

if __name__ == '__main__':
    setup()
